@@ -9,8 +9,12 @@
  */
 
 #include "eckit/eckit.h"
+#include "eckit/exception/Exceptions.h"
+#include "eckit/log/Log.h"
+
 #include "odc/core/MetaData.h"
 #include "odc/core/TablesReader.h"
+#include "odc/LibOdc.h"
 #include "odc/Reader.h"
 #include "odc/tools/CountTool.h"
 
@@ -43,7 +47,9 @@ void CountTool::run()
 		Log::error() << "Usage: ";
 		usage(parameters(0), Log::error());
 		Log::error() << std::endl;
-		return;
+        std::stringstream ss;
+        ss << "Expected at least 2 command line parameters";
+        throw UserError(ss.str());
 	}
 
 	unsigned long long n (0);
@@ -51,7 +57,7 @@ void CountTool::run()
     {
         const std::string fileName (parameters(i));
 
-        Log::debug() << "CountTool: counting " << fileName << std::endl;
+        LOG_DEBUG_LIB(LibOdc) << "CountTool: counting " << fileName << std::endl;
 
         n += rowCount(fileName);
     }
